From 3698ce4028fe16b6253be0ec3a63f1fc6fe58863 Mon Sep 17 00:00:00 2001
From: kpetridis <petridkon@gmail.com>
Date: Fri, 18 Mar 2022 17:00:26 +0200
Subject: [PATCH] Placement of the configuration inside the Service itself

---
 inc/Services/RealTimeForwardingControlService.hpp | 10 +++++++---
 1 file changed, 7 insertions(+), 3 deletions(-)

diff --git a/inc/Services/RealTimeForwardingControlService.hpp b/inc/Services/RealTimeForwardingControlService.hpp
index 58fc7973..03e992a6 100644
--- a/inc/Services/RealTimeForwardingControlService.hpp
+++ b/inc/Services/RealTimeForwardingControlService.hpp
@@ -5,14 +5,15 @@
 #include "Service.hpp"
 #include "ErrorHandler.hpp"
 #include "etl/vector.h"
+#include "Helpers/ForwardControlConfiguration.hpp"
 
 /**
  * Implementation of the ST[14] 'Real Time Forwarding Control Service' as defined in ECSS-E-ST-70-41C.
  *
  * @brief
  * The purpose of this Service is to control the forwarding of the stores telemetry to the ground stations. It
  * includes conditions for all the applications processes that are controlled by the Service, which determine whether
  * a message should be forwarded to the ground station through the corresponding virtual channel.
  *
  * @author Konstantinos Petridis <petridkon@gmail.com>
  */
@@ -46,6 +47,9 @@ private:
 	 */
 	bool appIsControlled(uint8_t applicationId);
 
+	ForwardControlConfiguration::ApplicationProcess applicationProcessConfiguration;
+	ForwardControlConfiguration::HousekeepingParameterReport housekeepingConfiguration;
+
 public:
 	/**
 	 * TC[14,1] 'Add report types to the application process forward control configuration'.
@@ -5,14 +5,15 @@
  *
  * @brief
- * The purpose of this Service is to control the forwarding of the stores telemetry to the ground stations. It
- * includes conditions for all the applications processes that are controlled by the Service, which determine whether
- * a message should be forwarded to the ground station through the corresponding virtual channel.
+ * The purpose of this Service is to control the forwarding of the stores telemetry to the ground station. It includes
+ * conditions for all the application processes that are controlled by the Service, which determine whether a message
+ * should be forwarded to the ground station, through the corresponding virtual channel.
  *
  * @author Konstantinos Petridis <petridkon@gmail.com>
-- 
GitLab